@@ -23,7 +23,7 @@ from notable import bottle, db, editor
 
 # Constants, and help with template lookup
 host = 'localhost'
-version = '0.0.6a'
+version = '0.0.7'
 static = os.path.join(root, 'static')
 bottle.TEMPLATE_PATH.insert(0, os.path.join(root, 'views'))
 log = logging.getLogger(__name__)
@@ -104,24 +104,22 @@ def getopts():
     parser = optparse.OptionParser(__doc__.strip())
     parser.add_option('-b', '--browser',
                       action='store_true',
-                      dest='browser',
                       help='Launch a browser')
     parser.add_option('-d', '--debug',
                       action='store_true',
-                      dest='debug',
                       help='Debug using a debug db')
     parser.add_option('-f', '--fork',
                       action='store_true',
-                      dest='fork',
                       help='Start the server in the background (fork)')
     parser.add_option('-p', '--port',
                       default=8082,
-                      dest='port',
                       help='TCP port to start the server on')
     parser.add_option('-r', '--restart',
                       action='store_true',
-                      dest='restart',
                       help='Restart if already running')
+    parser.add_option('-v', '--version',
+                      action='store_true',
+                      help='Print version number')
     return parser.parse_args(), parser
 
 def running(opts):
@@ -141,16 +139,20 @@ def run(opts):
     db.path = db.path + '.debug' if opts.debug else db.path
     db.prepare()
     bottle.run(host=host, port=opts.port)
+    return 0
 
 def main():
     logging.basicConfig(level=logging.DEBUG)
     (opts, _), _ = getopts()
     opts.port = int(opts.port) + 1 if opts.debug else int(opts.port)
+    if opts.version:
+        print('Notable version %s' % version)
+        return 0
     if opts.browser:
         threading.Thread(target=browser, args=[opts]).start()
     if opts.fork:
         fork()
-    run(opts)
+    return run(opts)
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
